==> spring-cloud-aws-context-1.2.4.RELEASE-sources.jar: org/springframework/cloud/aws/context/annotation/ConditionalOnAwsCloudEnvironment.java <==
/*
 * Copyright 2013-2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.cloud.aws.context.annotation;

import org.springframework.context.annotation.Conditional;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * {@link org.springframework.context.annotation.Conditional} annotation that returns true if the current JVM is started
 * inside an AWS cloud environment. Useful for beans that should only be created if the application context is
 * bootstrapped inside the AWS environment (e.g. beans that fetch meta data or beans that can only connect to AWS internal
 * services like Elasticache)
 *
 * @author Agim Emruli
 */
@Target({ElementType.TYPE, ElementType.METHOD})
@Retention(RetentionPolicy.RUNTIME)
@Documented
@Conditional(OnAwsCloudEnvironmentCondition.class)
public @interface ConditionalOnAwsCloudEnvironment {

}

==> spring-cloud-aws-context-2.1.1.RELEASE-sources.jar: org/springframework/cloud/aws/context/annotation/ConditionalOnAwsCloudEnvironment.java <==
/*
 * Copyright 2013-2019 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.cloud.aws.context.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.springframework.context.annotation.Conditional;

/**
 * {@link org.springframework.context.annotation.Conditional} annotation that returns true
 * if the current JVM is started inside an AWS cloud environment. Useful for beans that
 * should only be created if the application context is bootstrapped inside the AWS
 * environment (e.g. beans that fetch meta data or beans that can only connect to AWS
 * internal services like Elasticache)
 *
 * @author Agim Emruli
 */
@Target({ ElementType.TYPE, ElementType.METHOD })
@Retention(RetentionPolicy.RUNTIME)
@Documented
@Conditional(OnAwsCloudEnvironmentCondition.class)
public @interface ConditionalOnAwsCloudEnvironment {

}
